@@ -20,8 +20,8 @@
 #ifndef MAILTRANSPORT_TRANSPORTTYPE_P_H
 #define MAILTRANSPORT_TRANSPORTTYPE_P_H
 
-#include <QtCore/QSharedData>
-#include <QtCore/QString>
+#include <QSharedData>
+#include <QString>
 
 namespace MailTransport {
 /**
@@ -31,21 +31,23 @@ class TransportType::Private : public QSharedData
 {
 public:
     Private()
+        : mIsAkonadiResource(false)
     {
-        mType = -1;
     }
 
     Private(const Private &other)
         : QSharedData(other)
     {
-        mType = other.mType;
         mName = other.mName;
         mDescription = other.mDescription;
+        mIdentifier = other.mIdentifier;
+        mIsAkonadiResource = other.mIsAkonadiResource;
     }
 
-    int mType;
     QString mName;
     QString mDescription;
+    QString mIdentifier;
+    bool mIsAkonadiResource;
 };
 } // namespace MailTransport
 
