@@ -35,31 +35,34 @@ namespace MailTransport {
 class MAILTRANSPORT_EXPORT TransportComboBox : public QComboBox
 {
     Q_OBJECT
-
 public:
     /**
       Creates a new mail transport selection combo box.
       @param parent The paren widget.
     */
-    TransportComboBox(QWidget *parent = nullptr);
+    explicit TransportComboBox(QWidget *parent = nullptr);
 
-    ~TransportComboBox();
+    ~TransportComboBox() override;
 
     /**
       Returns identifier of the currently selected mail transport.
     */
-    int currentTransportId() const;
+    Q_REQUIRED_RESULT int currentTransportId() const;
 
     /**
       Selects the given transport.
       @param transportId The transport identifier.
+      @return return true if we success to find transportId
     */
-    void setCurrentTransport(int transportId);
+    Q_REQUIRED_RESULT bool setCurrentTransport(int transportId);
 
     /**
       Returns the type of the selected transport.
     */
-    QString transportType() const;
+    Q_REQUIRED_RESULT QString transportType() const;
+
+Q_SIGNALS:
+    void transportRemoved(int id, const QString &name);
 
 protected:
     void setTransportList(const QVector<int> &transportList);
